@@ -9,9 +9,14 @@ class _ElementKeywords(KeywordGroup):
         self._element_finder = ElementFinder()
 
     # Public, element lookups
-    def click_element_by_name(self, name):
-        """ Click element by name """
-        self._click_element_by_name(name)
+    def click_element(self, locator):
+        """Click element identified by `locator`.
+
+        Key attributes for arbitrary elements are `id` and `name`. See
+        `introduction` for details about locating elements.
+        """
+        # self._info("Clicking element '%s'." % locator)
+        self._element_find(locator, True, True).click()        
 
     def click_button(self, id_or_name):
         """ Click button """
@@ -102,7 +107,32 @@ class _ElementKeywords(KeywordGroup):
                 'tapCount':int(tap_count), 'element':element.id, 'duration':1}
         driver.execute_script('mobile: flick', args)
 
-    
+    def page_should_contain(self, text, loglevel='INFO'):
+        """Verifies that current page contains `text`.
+
+        If this keyword fails, it automatically logs the page source
+        using the log level specified with the optional `loglevel` argument.
+        Giving `NONE` as level disables logging.
+        """
+        if not text in self.log_source(loglevel):
+            self.log_source(loglevel)
+            raise AssertionError("Page should have contained text '%s' "
+                                 "but did not" % text)
+        self._info("Current page contains text '%s'." % text)
+
+    def page_should_not_contain(self, text, loglevel='INFO'):
+        """Verifies that current page not contains `text`.
+
+        If this keyword fails, it automatically logs the page source
+        using the log level specified with the optional `loglevel` argument.
+        Giving `NONE` as level disables logging.
+        """
+        if text in self.log_source(loglevel):
+            self.log_source(loglevel)
+            raise AssertionError("Page should not have contained text '%s' "
+                                 "but did not" % text)
+        self._info("Current page does not contains text '%s'." % text)
+
     # Private
 
     def _find_elements_by_tag_name(self, tag_name):
@@ -155,3 +185,13 @@ class _ElementKeywords(KeywordGroup):
             element.click()
         except Exception, e:
             raise Exception, 'Cannot click the element with name "%s"' % name
+
+    def _element_find(self, locator, first_only, required, tag=None):
+        application = self._current_application()
+        elements = self._element_finder.find(application, locator, tag)
+        if required and len(elements) == 0:
+            raise ValueError("Element locator '" + locator + "' did not match any elements.")
+        if first_only:
+            if len(elements) == 0: return None
+            return elements[0]
+        return elements
\ No newline at end of file
